@@ -71,9 +71,8 @@ void cTabFractal::InitWidgetNames() const
 {
 	QList<QWidget *> widgetList = findChildren<QWidget *>();
 
-	for (int i = 0; i < widgetList.size(); i++)
+	for (auto widget : widgetList)
 	{
-		QWidget *widget = widgetList[i];
 		QString oldName = widget->objectName();
 		if (oldName.size() > 0)
 		{
@@ -133,8 +132,8 @@ void cTabFractal::Init(bool firstTab, int _tabIndex)
 
 void cTabFractal::slotChangedComboFractal(int indexInComboBox)
 {
-	QString comboName = this->sender()->objectName();
-	int index = qobject_cast<QComboBox *>(this->sender())->itemData(indexInComboBox).toInt();
+	QString comboName = sender()->objectName();
+	int index = qobject_cast<QComboBox *>(sender())->itemData(indexInComboBox).toInt();
 
 	QString fullFormulaName = fractalList[index].nameInComboBox;
 	if (fractalList[index].internalID > 0)
@@ -286,9 +285,7 @@ void cTabFractal::FrameIterationFormulaSetWidgetsVisibility(bool visible) const
 	ui->checkBox_check_for_bailout->setVisible(visible);
 }
 
-void cTabFractal::ConnectSignals()
-{
-}
+void cTabFractal::ConnectSignals() {}
 
 void cTabFractal::MaterialSetVisible(bool visible) const
 {
