@@ -43,6 +43,7 @@ enum enumDEMethod
 {
 	preferredDEMethod = 0,
 	forceDeltaDEMethod = 1,
+	forceAnalyticDE = 2
 };
 
 enum enumDEFunctionType
@@ -53,7 +54,9 @@ enum enumDEFunctionType
 	logarithmicDEFunction = 2,
 	pseudoKleinianDEFunction = 3,
 	josKleinianDEFunction = 4,
+	// testingDEFunction = 5,
 	numberOfDEFunctions = 4, // used to prepare array
+	// numberOfDEFunctions = 5, // used to prepare array
 	withoutDEFunction = 99
 };
 
@@ -72,7 +75,7 @@ enum enumDEType
 	deltaDEType = 1
 };
 
-enum enumDEAnalyticFunction
+enum enumDEAnalyticFunction // DE function for non hybrid fractals
 {
 	analyticFunctionUndefined = -1,
 	analyticFunctionNone = 0,
@@ -93,6 +96,6 @@ enum enumColoringFunction
 	// coloringFunctionABox2 = 4, V2.14 removed
 	coloringFunctionDonut = 4,
 };
-};
+}; // namespace fractal
 
 #endif /* MANDELBULBER2_SRC_FRACTAL_ENUMS_H_ */
