@@ -1,7 +1,7 @@
 /**
  * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
  *                                             ,B" ]L,,p%%%,,,§;, "K
- * Copyright (C) 2014-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
+ * Copyright (C) 2014-18 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
  *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
  * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
  *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
@@ -46,9 +46,7 @@ cOneParameter::cOneParameter()
 	isEmpty = true;
 }
 
-cOneParameter::~cOneParameter()
-{
-}
+cOneParameter::~cOneParameter() = default;
 
 void cOneParameter::copy(const cOneParameter &other)
 {
@@ -241,7 +239,7 @@ QString cOneParameter::GetValueByEnumeration() const
 	{
 		qWarning() << "Enumeration not found, cannot find index: " << index << " in QStringList "
 							 << enumLookup;
-		return this->Get<QString>(valueActual);
+		return Get<QString>(valueActual);
 	}
 }
 
